@@ -1,4 +1,5 @@
-""" 
+""" Dimarray module
+    ===============
 """
 import warnings
 import core
@@ -8,12 +9,15 @@ import lib.transform
 
 from config import set_option, get_option, print_options, rcParams, rcParamsHelp
 from core import *
-from dataset import Dataset
+from dataset import Dataset, stack_ds, concatenate_ds
+from datasets import get_datadir, get_ncfile
 #from lib.transform import interp1d, interp2d, apply_recursive
 from lib import *
 
+from dimarray.version import version as __version__
+
 try:
-    from io.nc import read as read_nc, summary as summary_nc
+    from io.nc import read_nc, summary_nc, write_nc #, read_nc_axes
     _ncio = True
 
 except ImportError:
