@@ -11,23 +11,25 @@ def pandas_obj(values, *axes):
 
     n = pd.np.array(values).ndim
     if n > len(pandas_classes):
-	raise Exception("No pandas class matches that dimension: "+str(n))
+        raise Exception("No pandas class matches that dimension: "+str(n))
 
     elif n == 0:
-	return values
+        return values
 
     else:
-	cls = pandas_classes[n-1] 
-	return cls(values, *axes)
+        cls = pandas_classes[n-1] 
+        return cls(values, *axes)
 
 def ndindex(indices, pos):
     """ return the N-D index from an along-axis index
 
-    inputs:
-	indices: `int` or `list` or `slice`
-	pos : axis position
-    returns:
-	tuple
+    Parameters
+    ----------
+        indices: `int` or `list` or `slice`
+        pos : axis position
+    Returns
+    -------
+        tuple
     """
     return (slice(None),)*pos + np.index_exp[indices]
 
@@ -40,12 +42,12 @@ def is_DimArray(obj):
 def is_array1d_equiv(a):
     " test if a is convertible to a 1-D array of scalar"
     if isinstance(a, np.ndarray) and a.ndim == 1:
-	res = True
+        res = True
     else:
-	try:
-	    a = np.asarray(a)
-	    res = a.ndim == 1 and ((a[0] is str) or np.isscalar(a[0]))
-	except:
-	    res = False
+        try:
+            a = np.asarray(a)
+            res = a.ndim == 1 and ((a[0] is str) or np.isscalar(a[0]))
+        except:
+            res = False
     return res
 
